@@ -272,8 +272,12 @@ def getBetweenDay(begin_date: str, end_date: str) -> list:
     :return:<class 'list'> ['2020-01-01', '2020-01-02', '2020-01-03', '2020-01-04', '2020-01-05']
     """
     date_list = []
-    begin_date = datetime.datetime.strptime(begin_date, "%Y-%m-%d")
-    end_date = datetime.datetime.strptime(end_date, "%Y-%m-%d")
+    try :
+        begin_date = datetime.datetime.strptime(begin_date, "%Y-%m-%d")
+        end_date = datetime.datetime.strptime(end_date, "%Y-%m-%d")
+    except:
+        begin_date = datetime.datetime.strptime(begin_date, "%Y-%m-%d %H:%M:%S")
+        end_date = datetime.datetime.strptime(end_date, "%Y-%m-%d %H:%M:%S")
     while begin_date <= end_date:
         date_str = begin_date.strftime("%Y-%m-%d")
         date_list.append(date_str)
@@ -411,8 +415,26 @@ def get_taobao_time():
         return json_data
 
 
+def split_time_h(start_time: str, end_time: str):
+    """
+    将给定的时间按小时拆分
+    :param start_time: %Y-%m-%d %H:%M:%S
+    :param end_time: %Y-%m-%d %H:%M:%S
+    :return:
+    """
+    hour_list = []
+    date_list = getBetweenDay(start_time, end_time)
+    for day in date_list:
+        for hour in range(24):
+            day_hour = f"{day} {hour:02d}:00:00"
+            print(day_hour)
+            hour_list.append(day_hour)
+    return hour_list
+
+
 if __name__ == '__main__':
-    now_time = get_now_time("%H:%M:%S")
-    print(now_time)
-    flag = judge_time(now_time, "02:00:00", "05:00:00", year=False)
-    print(flag)
+    # now_time = get_now_time("%H:%M:%S")
+    # print(now_time)
+    # flag = judge_time(now_time, "02:00:00", "05:00:00", year=False)
+    # print(flag)
+    print(split_time_h("2022-03-05 16:41:50", "2022-03-13 16:41:50"))
